@@ -2,7 +2,7 @@ from concurrent import futures
 import logging
 import grpc
 
-from dv_pyclient.grpc.datavore import dataSources_pb2_grpc as rpc
+from dv_pyclient.grpc import dataSources_pb2_grpc as rpc
 from dv_pyclient.grpc import test_datasource_server as ds
 
 
